@@ -2,7 +2,7 @@ package Mojolicious::Plugin::RoutesAuthDBI;
 use Mojo::Base 'Mojolicious::Plugin::Authentication';
 use Mojo::Loader qw(load_class);
 
-our $VERSION = '0.400';
+our $VERSION = '0.401';
 
 my $access;# 
 my $pkg = __PACKAGE__;
@@ -209,17 +209,17 @@ sub access {# add_condition
 
 Доброго всем
 
-¡ ¡ ¡ ALL GLORY TO GLORIA ! ! !
-
 =head1 Mojolicious::Plugin::RoutesAuthDBI
 
+¡ ¡ ¡ ALL GLORY TO GLORIA ! ! !
+
 =head1 NAME
 
 Mojolicious::Plugin::RoutesAuthDBI - Generate routes from sql-table, make authentication and make restrict access (authorization) to route with users/roles tables. Plugin makes an auth operations throught the plugin L<Mojolicious::Plugin::Authentication> on which is based.
 
 =head1 DB DESIGN DIAGRAM
 
-First of all see L<SVG|https://github.com/mche/Mojolicious-Plugin-RoutesAuthDBI/blob/master/Diagram.svg>  or L<PNG|http://i.imgur.com/sXHF4pU.png>
+First of all see L<SVG|https://github.com/mche/Mojolicious-Plugin-RoutesAuthDBI/blob/master/Diagram.svg>  or L<PNG|http://i.imgur.com/CwqiB4f.png>
 
 =head1 SYNOPSIS
 
